import { create } from 'zustand'
import { getInfoAgentOnline, initChatService } from '@/feature/messenger/services/chat/ChatService'
import { ListConversationModel } from '@/feature/messenger/models/ListConversationModel'
import useConversationsStore from '@/feature/messenger/store/chat_store/useConversationsStore'
import PermissionsValue, { PermissionsModel, setPermissionsValue } from '@/feature/messenger/models/PermissionsModel'


type TypeConfigChatActions = {
    setChatbot: (chatbot: object) => void,
    setIdChatbot: (idChatbot: string) => void,
    initChatService: (id_chatbot: string) => void,
    getAgentsLogged: (id_chatbot: string) => void
}
type TypeConfigChat = {
    idChatbot:string,
    chatbot:object,
    permisions: PermissionsModel,
    agentsLogged: [],
    actions: TypeConfigChatActions
}

const setListConversation = (conversation: ListConversationModel[]) => {
    useConversationsStore.getState().actions.setListConversation(orderConversations(conversation))
}
const orderConversations = (conversations: ListConversationModel[]) => {
    return conversations.sort((a, b) => {
        if (a.fecha < b.fecha) return 1;
        if (a.fecha > b.fecha) return -1;
        return 0;
    })
}
const useConfigChatStore = create<TypeConfigChat>((set) => ({
    idChatbot: '',
    chatbot: {},
    permisions: PermissionsValue(),
    agentsLogged: [],
    actions: {
        setChatbot: (chatbot: object) => set({ chatbot: chatbot }),
        setIdChatbot: (idChatbot: string) => set({ idChatbot: idChatbot }),
        initChatService: (id_chatbot: string) => {
            if (id_chatbot === '') {
                return
            }
            set({ idChatbot: id_chatbot })
            initChatService(id_chatbot).then((response) => {
                if (response.success === true) {
                    set({ chatbot: response.data.chatbot })
                    set({ permisions: setPermissionsValue(response.data.agentPermissions) })
                    setListConversation(response.data.conversations)
                }
            })
        },
        getAgentsLogged: (id_chatbot: string) => {
            getInfoAgentOnline(id_chatbot).then((response) => {
                if (response.success === true) {
                    set({ agentsLogged: response.data })
                }
            })
        }
    }
}))

export default useConfigChatStore